import {createFactory} from "./createModules/factory/createFactory";
import {createService} from "./createModules/service/createService";
import {createStore} from "./createModules/store/createStore";
import {createApiRepositories} from "./createModules/repositories/createApiRepositories";
import {createForm} from "./createModules/form/createForm";
import {createModels} from "./createModules/models/createModels";

const axios = require('axios');
const fs = require('fs');

const getPostmanData = () => {
    if (!process.argv[2]) {
        console.log("No url")
        return;
    }

    const url = process.argv[2].replace(" ", "")
        .replace(":\\", "://")
        .replace("\\", "/")
        .replace("\\", "/")
        .replace("\\", "/")

    console.log("Your url", url)

    axios.get(url)
        .then((res) => {
            createFolders(res.data)
        })
        .catch((error) => {
            console.log("axios error, check if the url is correct");
            console.log("Error", error);
        })
}


const createFolders = (postmanData) => {
    const modulesPath = '../../src/modules'
    const srcPath = '../../src'

    fs.stat(srcPath, (err) => {
        if (!err) {
            createModules();
        } else if (err.code === 'ENOENT') {
            fs.mkdir(srcPath, () => {
                createModules();
            })
        }
    });

    const createModules = () => {
        fs.mkdir(modulesPath, () => {
            postmanData.item.map((essence) => {
                const essencePath = `${modulesPath}/${essence.name.toLowerCase()}`

                fs.mkdir(essencePath, () => {
                    createFoldersInEssence(essence, essencePath)
                })
            })
        });
    }
}

const createFoldersInEssence = (essenceData, essencePath) => {
    const formsPath = `${essencePath}/forms`
    const repositoriesPath = `${essencePath}/repositories`
    const modelsPath = `${essencePath}/models`

    fs.mkdir(formsPath, () => {
        createForm(essenceData, formsPath)
    })

    fs.mkdir(repositoriesPath, () => {
        createApiRepositories(essenceData, repositoriesPath)
    })

    fs.mkdir(modelsPath, () => {
        createModels(modelsPath)
    })

    createFactory(essenceData.name, essencePath)
    createService(essenceData, essencePath)
    createStore(essenceData, essencePath)

    console.log(essenceData.name, "create success")
}

getPostmanData()


